==> lnl-2.1.10.tar.gz: lnl-2.1.10/src/fight_prot.h <==
/* fight.c */
bool_t	bash( chr_t *chr, chr_t *chr2, attack_t *dflt_attack );
bool_t	set_attack_chr_bash( attack_t *attack, chr_t *chr, bool_t flg_ave );
bool_t	set_attack_mbr_bash(
	attack_t *attack, mbr_t *mbr, bool_t flg_ave
);
bool_t	set_attack_mnstr_bash(
	attack_t *attack, mnstr_t *mnstr, bool_t flg_ave
);
bool_t	throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack );
bool_t	set_attack_chr_throw( attack_t *attack, chr_t *chr, bool_t flg_ave );
bool_t	set_attack_mbr_throw(
	attack_t *attack, mbr_t *mbr, bool_t flg_ave
);
bool_t	set_attack_mnstr_throw(
	attack_t *attack, mnstr_t *mnstr, bool_t flg_ave
);
bool_t	chk_dagger( const wpn_tab_t *arw_tab );
bool_t	chk_bow( const wpn_tab_t *arw_tab, const wpn_tab_t *bow_tab );
attack_t	*get_attack(
	bool_t flg_ave, attack_t *ls, bool_t flg_throw, bool_t flg_monk
);
attack_t	*get_attack_ave(
	attack_t *ls, bool_t flg_throw, bool_t flg_monk
);
attack_t	*get_attack_randm( attack_t *ls );
bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack );
bool_t	zap_wand_mbr_attack( mbr_t *mbr, resi_kind_t resi );
bool_t	spell_attack(
	chr_t *o_p, chr_t *d_p,
	resi_kind_t resi, bool_t flg_stick,
	abl_kind_t abl, rate_t rate
);
bool_t	chr_break_door( chr_t *chr, long dr_n );
bool_t	chr_break_trap( chr_t *chr, trap_t *trap );
bool_t	chr_break_item( chr_t *chr, item_t *item );
bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
long	get_hit( chr_t *p, const attack_t *attack );
long	get_dam( chr_t *p, const attack_t *attack );
long	get_def( chr_t *p );
abl_kind_t	get_def_abl( chr_t *p );
long	get_armor_def( chr_t *p, abl_kind_t abl );
long	get_ac( chr_t *p );
rate_t	get_crtcl( chr_t *o_p, chr_t *d_p, const attack_t *attack );
rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack );
rate_t	get_armor_crtcl( chr_t *p );
long	get_dam_wand( chr_t *p );
long	get_dam_spell( chr_t *p, abl_kind_t abl );
rate_t	get_resi( chr_t *p, resi_kind_t resi );
char	*get_msg_attack( const attack_t *attack );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/fight_prot.h <==
/* fight.c */
bool_t	bash( chr_t *chr, chr_t *chr2, attack_t *dflt_attack );
bool_t	set_attack_chr_bash( attack_t *attack, chr_t *chr, bool_t flg_ave );
bool_t	set_attack_mbr_bash(
	attack_t *attack, mbr_t *mbr, bool_t flg_ave
);
bool_t	set_attack_mnstr_bash(
	attack_t *attack, mnstr_t *mnstr, bool_t flg_ave
);
bool_t	throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack );
bool_t	set_attack_chr_throw( attack_t *attack, chr_t *chr, bool_t flg_ave );
bool_t	set_attack_mbr_throw(
	attack_t *attack, mbr_t *mbr, bool_t flg_ave
);
bool_t	set_attack_mnstr_throw(
	attack_t *attack, mnstr_t *mnstr, bool_t flg_ave
);
bool_t	chk_dagger( const wpn_tab_t *arw_tab );
bool_t	chk_bow( const wpn_tab_t *arw_tab, const wpn_tab_t *bow_tab );
attack_t	*get_attack(
	bool_t flg_ave, attack_t *ls,
	bool_t flg_bash, bool_t flg_monk,
	bool_t flg_throw, bool_t flg_spell
);
attack_t	*get_attack_ave(
	attack_t *ls,
	bool_t flg_bash, bool_t flg_monk,
	bool_t flg_throw, bool_t flg_spell
);
attack_t	*get_attack_randm(
	attack_t *ls,
	bool_t flg_bash, bool_t flg_monk,
	bool_t flg_throw, bool_t flg_spell
);
ratio_t	calc_attack_sum(
	attack_t *ls,
	bool_t flg_bash, bool_t flg_monk,
	bool_t flg_throw, bool_t flg_spell
);
bool_t	fight( chr_t *o_p, chr_t *d_p, const attack_t *attack );
bool_t	zap_wand_mbr_attack( mbr_t *mbr, resi_kind_t resi );
bool_t	spell_attack(
	chr_t *o_p, chr_t *d_p,
	resi_kind_t resi, bool_t flg_stick,
	abl_kind_t abl, rate_t rate
);
void	added_fx( chr_t *chr, resi_kind_t resi );
void	fight_fx( chr_t *o_p, chr_t *d_p, const attack_t *attack );
bool_t	chr_break_door( chr_t *chr, long dr_n );
bool_t	chr_break_trap( chr_t *chr, trap_t *trap );
bool_t	chr_break_item( chr_t *chr, item_t *item );
bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
bool_t	chk_magic_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw );
long	get_hit( chr_t *p, const attack_t *attack );
long	get_dam( chr_t *p, const attack_t *attack );
long	get_def( chr_t *p );
abl_kind_t	get_def_abl( chr_t *p );
long	get_armor_def( chr_t *p, abl_kind_t abl );
long	get_ac( chr_t *p );
rate_t	get_crtcl( chr_t *o_p, chr_t *d_p, const attack_t *attack );
rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack );
rate_t	get_armor_crtcl( chr_t *p );
long	get_dam_wand( chr_t *p );
long	get_dam_spell( chr_t *p, abl_kind_t abl );
rate_t	get_resi_def( chr_t *p, resi_kind_t resi );
char	*get_msg_attack( const attack_t *attack );
